# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ClientSystemHealthcheckV2Snapshot(BaseModel):
    """
    ClientSystemHealthcheckV2Snapshot
    """ # noqa: E501
    client_id: Optional[StrictStr] = None
    client_name: Optional[StrictStr] = None
    client_uid: Optional[StrictStr] = None
    error_json: Optional[List[StrictInt]] = None
    error_message: Optional[StrictStr] = None
    graph_json: Optional[List[StrictInt]] = None
    graph_version: Optional[StrictInt] = None
    id: Optional[StrictStr] = None
    integration_mode: Optional[StrictStr] = None
    metrics_json: Optional[List[StrictInt]] = None
    org_id: Optional[StrictStr] = None
    org_name: Optional[StrictStr] = None
    org_uid: Optional[StrictStr] = None
    result_success: Optional[StrictBool] = None
    run_date: Optional[StrictStr] = None
    status: Optional[StrictStr] = None
    summary_json: Optional[List[StrictInt]] = None
    ts_finished: Optional[StrictStr] = None
    ts_started: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["client_id", "client_name", "client_uid", "error_json", "error_message", "graph_json", "graph_version", "id", "integration_mode", "metrics_json", "org_id", "org_name", "org_uid", "result_success", "run_date", "status", "summary_json", "ts_finished", "ts_started"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ClientSystemHealthcheckV2Snapshot from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ClientSystemHealthcheckV2Snapshot from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "client_id": obj.get("client_id"),
            "client_name": obj.get("client_name"),
            "client_uid": obj.get("client_uid"),
            "error_json": obj.get("error_json"),
            "error_message": obj.get("error_message"),
            "graph_json": obj.get("graph_json"),
            "graph_version": obj.get("graph_version"),
            "id": obj.get("id"),
            "integration_mode": obj.get("integration_mode"),
            "metrics_json": obj.get("metrics_json"),
            "org_id": obj.get("org_id"),
            "org_name": obj.get("org_name"),
            "org_uid": obj.get("org_uid"),
            "result_success": obj.get("result_success"),
            "run_date": obj.get("run_date"),
            "status": obj.get("status"),
            "summary_json": obj.get("summary_json"),
            "ts_finished": obj.get("ts_finished"),
            "ts_started": obj.get("ts_started")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reports_report_facets_response import ReportsReportFacetsResponse

class TestReportsReportFacetsResponse(unittest.TestCase):
    """ReportsReportFacetsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportsReportFacetsResponse:
        """Test ReportsReportFacetsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportsReportFacetsResponse`
        """
        model = ReportsReportFacetsResponse()
        if include_optional:
            return ReportsReportFacetsResponse(
                concepts = [
                    neurograph.v1.models.reports/facet_item.reports.FacetItem(
                        count = 56, 
                        value = '', )
                    ],
                error = '',
                themes = [
                    neurograph.v1.models.reports/facet_item.reports.FacetItem(
                        count = 56, 
                        value = '', )
                    ],
                topics = [
                    neurograph.v1.models.reports/facet_item.reports.FacetItem(
                        count = 56, 
                        value = '', )
                    ],
                types = [
                    neurograph.v1.models.reports/facet_item.reports.FacetItem(
                        count = 56, 
                        value = '', )
                    ]
            )
        else:
            return ReportsReportFacetsResponse(
        )
        """

    def testReportsReportFacetsResponse(self):
        """Test ReportsReportFacetsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class OpportunitiesOpportunityResponse(BaseModel):
    """
    OpportunitiesOpportunityResponse
    """ # noqa: E501
    action_description: Optional[StrictStr] = None
    category: Optional[StrictStr] = None
    client_id: Optional[StrictStr] = None
    comparison_context: Optional[StrictStr] = None
    comparison_stat: Optional[StrictStr] = None
    comparison_type: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    display_order: Optional[StrictInt] = None
    effort_level: Optional[StrictStr] = None
    error: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    organization_id: Optional[StrictStr] = None
    priority_tier: Optional[StrictStr] = None
    roi_metric: Optional[StrictStr] = None
    roi_progress: Optional[StrictInt] = None
    roi_value: Optional[StrictStr] = None
    status: Optional[StrictStr] = None
    subtitle: Optional[StrictStr] = None
    ts_created: Optional[StrictStr] = None
    ts_updated: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["action_description", "category", "client_id", "comparison_context", "comparison_stat", "comparison_type", "description", "display_order", "effort_level", "error", "id", "name", "organization_id", "priority_tier", "roi_metric", "roi_progress", "roi_value", "status", "subtitle", "ts_created", "ts_updated"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OpportunitiesOpportunityResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OpportunitiesOpportunityResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "action_description": obj.get("action_description"),
            "category": obj.get("category"),
            "client_id": obj.get("client_id"),
            "comparison_context": obj.get("comparison_context"),
            "comparison_stat": obj.get("comparison_stat"),
            "comparison_type": obj.get("comparison_type"),
            "description": obj.get("description"),
            "display_order": obj.get("display_order"),
            "effort_level": obj.get("effort_level"),
            "error": obj.get("error"),
            "id": obj.get("id"),
            "name": obj.get("name"),
            "organization_id": obj.get("organization_id"),
            "priority_tier": obj.get("priority_tier"),
            "roi_metric": obj.get("roi_metric"),
            "roi_progress": obj.get("roi_progress"),
            "roi_value": obj.get("roi_value"),
            "status": obj.get("status"),
            "subtitle": obj.get("subtitle"),
            "ts_created": obj.get("ts_created"),
            "ts_updated": obj.get("ts_updated")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class ReportingDailyMetric(BaseModel):
    """
    ReportingDailyMetric
    """ # noqa: E501
    aov: Optional[Union[StrictFloat, StrictInt]] = None
    avg_ltv_original: Optional[Union[StrictFloat, StrictInt]] = None
    cohort_customers: Optional[StrictInt] = Field(default=None, description="LTV Metrics (cohort-based)")
    conversion_rate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="DEPRECATED: Use VisitorConversionRate instead")
    customer_conversion_rate: Optional[Union[StrictFloat, StrictInt]] = None
    customers_with_purchases: Optional[StrictInt] = None
    data_quality_flag: Optional[StrictStr] = None
    iqr_avg_ltv: Optional[Union[StrictFloat, StrictInt]] = None
    ltv_outlier_count: Optional[StrictInt] = None
    median_ltv: Optional[Union[StrictFloat, StrictInt]] = None
    p25_ltv: Optional[Union[StrictFloat, StrictInt]] = None
    p75_ltv: Optional[Union[StrictFloat, StrictInt]] = None
    period_revenue: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Revenue")
    persona_name: Optional[StrictStr] = None
    persona_seed_id: Optional[StrictStr] = None
    rpv: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="RPV Metrics (Revenue / All Visitors)")
    rpv_iqr: Optional[Union[StrictFloat, StrictInt]] = None
    rpv_median: Optional[Union[StrictFloat, StrictInt]] = None
    rpv_outlier_count: Optional[StrictInt] = None
    rpv_p25: Optional[Union[StrictFloat, StrictInt]] = None
    rpv_p75: Optional[Union[StrictFloat, StrictInt]] = None
    rpv_trimmed: Optional[Union[StrictFloat, StrictInt]] = None
    rpv_winsorized: Optional[Union[StrictFloat, StrictInt]] = None
    total_customers: Optional[StrictInt] = Field(default=None, description="Customer Metrics (Shopify-matched)")
    total_visitors: Optional[StrictInt] = Field(default=None, description="Visitor Metrics (hem-based)")
    trimmed_avg_ltv: Optional[Union[StrictFloat, StrictInt]] = None
    visitor_conversion_rate: Optional[Union[StrictFloat, StrictInt]] = None
    visitors_with_purchases: Optional[StrictInt] = None
    winsorized_avg_ltv: Optional[Union[StrictFloat, StrictInt]] = None
    __properties: ClassVar[List[str]] = ["aov", "avg_ltv_original", "cohort_customers", "conversion_rate", "customer_conversion_rate", "customers_with_purchases", "data_quality_flag", "iqr_avg_ltv", "ltv_outlier_count", "median_ltv", "p25_ltv", "p75_ltv", "period_revenue", "persona_name", "persona_seed_id", "rpv", "rpv_iqr", "rpv_median", "rpv_outlier_count", "rpv_p25", "rpv_p75", "rpv_trimmed", "rpv_winsorized", "total_customers", "total_visitors", "trimmed_avg_ltv", "visitor_conversion_rate", "visitors_with_purchases", "winsorized_avg_ltv"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ReportingDailyMetric from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ReportingDailyMetric from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "aov": obj.get("aov"),
            "avg_ltv_original": obj.get("avg_ltv_original"),
            "cohort_customers": obj.get("cohort_customers"),
            "conversion_rate": obj.get("conversion_rate"),
            "customer_conversion_rate": obj.get("customer_conversion_rate"),
            "customers_with_purchases": obj.get("customers_with_purchases"),
            "data_quality_flag": obj.get("data_quality_flag"),
            "iqr_avg_ltv": obj.get("iqr_avg_ltv"),
            "ltv_outlier_count": obj.get("ltv_outlier_count"),
            "median_ltv": obj.get("median_ltv"),
            "p25_ltv": obj.get("p25_ltv"),
            "p75_ltv": obj.get("p75_ltv"),
            "period_revenue": obj.get("period_revenue"),
            "persona_name": obj.get("persona_name"),
            "persona_seed_id": obj.get("persona_seed_id"),
            "rpv": obj.get("rpv"),
            "rpv_iqr": obj.get("rpv_iqr"),
            "rpv_median": obj.get("rpv_median"),
            "rpv_outlier_count": obj.get("rpv_outlier_count"),
            "rpv_p25": obj.get("rpv_p25"),
            "rpv_p75": obj.get("rpv_p75"),
            "rpv_trimmed": obj.get("rpv_trimmed"),
            "rpv_winsorized": obj.get("rpv_winsorized"),
            "total_customers": obj.get("total_customers"),
            "total_visitors": obj.get("total_visitors"),
            "trimmed_avg_ltv": obj.get("trimmed_avg_ltv"),
            "visitor_conversion_rate": obj.get("visitor_conversion_rate"),
            "visitors_with_purchases": obj.get("visitors_with_purchases"),
            "winsorized_avg_ltv": obj.get("winsorized_avg_ltv")
        })
        return _obj





# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.pixel_client_pixel_totals import PixelClientPixelTotals

class TestPixelClientPixelTotals(unittest.TestCase):
    """PixelClientPixelTotals unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PixelClientPixelTotals:
        """Test PixelClientPixelTotals
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PixelClientPixelTotals`
        """
        model = PixelClientPixelTotals()
        if include_optional:
            return PixelClientPixelTotals(
                avg_enrichment_rate_pct = 1.337,
                avg_match_rate_pct = 1.337,
                temporal_match_pct = 1.337,
                temporal_match_total = 56,
                total_enriched = 56,
                total_estimated_cost = 1.337,
                total_matched = 56,
                total_pageviews = 56,
                total_sessions = 56,
                total_visitors = 56,
                vendor_match_pct = 1.337,
                vendor_match_total = 56
            )
        else:
            return PixelClientPixelTotals(
        )
        """

    def testPixelClientPixelTotals(self):
        """Test PixelClientPixelTotals"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_model_job_summary import ReportingModelJobSummary

class TestReportingModelJobSummary(unittest.TestCase):
    """ReportingModelJobSummary unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingModelJobSummary:
        """Test ReportingModelJobSummary
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingModelJobSummary`
        """
        model = ReportingModelJobSummary()
        if include_optional:
            return ReportingModelJobSummary(
                active_build = 56,
                assignment_date = '',
                build_timestamp = '',
                client_id = '',
                client_name = '',
                job_id = '',
                model_type = '',
                model_version = '',
                org_name = '',
                prediction_count = 56
            )
        else:
            return ReportingModelJobSummary(
        )
        """

    def testReportingModelJobSummary(self):
        """Test ReportingModelJobSummary"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_organization_brand import ClientOrganizationBrand

class TestClientOrganizationBrand(unittest.TestCase):
    """ClientOrganizationBrand unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientOrganizationBrand:
        """Test ClientOrganizationBrand
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientOrganizationBrand`
        """
        model = ClientOrganizationBrand()
        if include_optional:
            return ClientOrganizationBrand(
                background_img_url = '',
                color1 = '',
                color2 = '',
                color3 = '',
                color4 = '',
                color5 = '',
                id = '',
                logo_img_url = '',
                primary_color = '',
                secondary_color = '',
                tertiary_color = ''
            )
        else:
            return ClientOrganizationBrand(
        )
        """

    def testClientOrganizationBrand(self):
        """Test ClientOrganizationBrand"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_enrichment_artifact_update_status_request import KnowledgeEnrichmentArtifactUpdateStatusRequest

class TestKnowledgeEnrichmentArtifactUpdateStatusRequest(unittest.TestCase):
    """KnowledgeEnrichmentArtifactUpdateStatusRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeEnrichmentArtifactUpdateStatusRequest:
        """Test KnowledgeEnrichmentArtifactUpdateStatusRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeEnrichmentArtifactUpdateStatusRequest`
        """
        model = KnowledgeEnrichmentArtifactUpdateStatusRequest()
        if include_optional:
            return KnowledgeEnrichmentArtifactUpdateStatusRequest(
                agent_engine_run_id = '',
                attempt_count = 56,
                cloud_run_execution_id = '',
                completed_at = '',
                last_error = '',
                started_at = '',
                status = 'RUNNING'
            )
        else:
            return KnowledgeEnrichmentArtifactUpdateStatusRequest(
        )
        """

    def testKnowledgeEnrichmentArtifactUpdateStatusRequest(self):
        """Test KnowledgeEnrichmentArtifactUpdateStatusRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.api.client_api import ClientApi


class TestClientApi(unittest.TestCase):
    """ClientApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ClientApi()

    def tearDown(self) -> None:
        pass

    def test_api_v1_client_personas_client_id_assignment_stats_get(self) -> None:
        """Test case for api_v1_client_personas_client_id_assignment_stats_get

        Get Client's Persona Assignment Statistics
        """
        pass

    def test_api_v1_client_personas_client_id_get(self) -> None:
        """Test case for api_v1_client_personas_client_id_get

        Get Client's Personas
        """
        pass

    def test_api_v1_client_url_client_id_get(self) -> None:
        """Test case for api_v1_client_url_client_id_get

        Get client's URLs
        """
        pass

    def test_api_v1_client_url_post(self) -> None:
        """Test case for api_v1_client_url_post

        Upsert a Client Url
        """
        pass

    def test_api_v1_client_url_probe_client_id_post(self) -> None:
        """Test case for api_v1_client_url_probe_client_id_post

        Trigger client URL probes
        """
        pass

    def test_api_v1_client_url_snapshot_probe_id_get(self) -> None:
        """Test case for api_v1_client_url_snapshot_probe_id_get

        Get a client's URL snapshot by probe id
        """
        pass

    def test_api_v1_clients_client_id_get(self) -> None:
        """Test case for api_v1_clients_client_id_get

        Get Client by ID
        """
        pass

    def test_api_v1_clients_client_id_healthcheck_latest_get(self) -> None:
        """Test case for api_v1_clients_client_id_healthcheck_latest_get

        Get newest healthcheck entry
        """
        pass

    def test_api_v1_clients_client_id_healthcheck_post(self) -> None:
        """Test case for api_v1_clients_client_id_healthcheck_post

        Create healthcheck entry
        """
        pass

    def test_api_v1_clients_client_id_healthcheck_rollup_get(self) -> None:
        """Test case for api_v1_clients_client_id_healthcheck_rollup_get

        Get client healthcheck boolean rollup
        """
        pass

    def test_api_v1_clients_client_id_slack_message_post(self) -> None:
        """Test case for api_v1_clients_client_id_slack_message_post

        Send a Slack message to a client's configured Slack channel
        """
        pass

    def test_api_v1_clients_client_id_users_get(self) -> None:
        """Test case for api_v1_clients_client_id_users_get

        Client's assigned users and their permissions
        """
        pass

    def test_api_v1_clients_get(self) -> None:
        """Test case for api_v1_clients_get

        Get Clients
        """
        pass

    def test_api_v1_clients_post(self) -> None:
        """Test case for api_v1_clients_post

        Upsert a Client
        """
        pass

    def test_api_v2_clients_client_id_system_healthcheck_latest_get(self) -> None:
        """Test case for api_v2_clients_client_id_system_healthcheck_latest_get

        Get latest system healthcheck snapshot
        """
        pass

    def test_api_v2_clients_client_id_system_healthcheck_run_post(self) -> None:
        """Test case for api_v2_clients_client_id_system_healthcheck_run_post

        Trigger system healthcheck run
        """
        pass

    def test_api_v2_system_healthcheck_latest_get(self) -> None:
        """Test case for api_v2_system_healthcheck_latest_get

        Get latest system healthcheck snapshots
        """
        pass

    def test_api_v2_system_healthcheck_run_post(self) -> None:
        """Test case for api_v2_system_healthcheck_run_post

        Trigger system healthcheck run for all clients
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_customer_cycle_metrics import ReportingCustomerCycleMetrics

class TestReportingCustomerCycleMetrics(unittest.TestCase):
    """ReportingCustomerCycleMetrics unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingCustomerCycleMetrics:
        """Test ReportingCustomerCycleMetrics
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingCustomerCycleMetrics`
        """
        model = ReportingCustomerCycleMetrics()
        if include_optional:
            return ReportingCustomerCycleMetrics(
                count = 56,
                cycle_days = 56,
                display_value = '',
                median_days = 56,
                tiers = neurograph.v1.models.reporting/cycle_tiers.reporting.CycleTiers(
                    fast = 56, 
                    slow = 56, 
                    typical = 56, )
            )
        else:
            return ReportingCustomerCycleMetrics(
        )
        """

    def testReportingCustomerCycleMetrics(self):
        """Test ReportingCustomerCycleMetrics"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.opportunities_opportunity_create_request import OpportunitiesOpportunityCreateRequest

class TestOpportunitiesOpportunityCreateRequest(unittest.TestCase):
    """OpportunitiesOpportunityCreateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OpportunitiesOpportunityCreateRequest:
        """Test OpportunitiesOpportunityCreateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OpportunitiesOpportunityCreateRequest`
        """
        model = OpportunitiesOpportunityCreateRequest()
        if include_optional:
            return OpportunitiesOpportunityCreateRequest(
                action_description = '',
                category = '',
                client_id = '',
                comparison_context = '',
                comparison_stat = '',
                comparison_type = '',
                description = '',
                display_order = 56,
                effort_level = '',
                name = '',
                organization_id = '',
                priority_tier = '',
                roi_metric = '',
                roi_progress = 56,
                roi_value = '',
                subtitle = ''
            )
        else:
            return OpportunitiesOpportunityCreateRequest(
        )
        """

    def testOpportunitiesOpportunityCreateRequest(self):
        """Test OpportunitiesOpportunityCreateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
